Subject: [bug#66896] [PATCH v2 1/5] gnu: qd: Use G-expressions.

From: Sharlatan Hellseher <[email-masked]>
Date: Sat, 4 Nov 2023 01:58:51 +0000

* gnu/packages/multiprecision.scm (qd): Adjust package style by using
G-expressions.

Change-Id: I9265979343e67d1d9e9e69b7b071ea1e429d3ee4
---
 gnu/packages/multiprecision.scm | 25 +++++++++++++------------
 1 file changed, 13 insertions(+), 12 deletions(-)

diff --git a/gnu/packages/multiprecision.scm b/gnu/packages/multiprecision.scm
index 3aa5dccfab..11afcfe4a0 100644
--- a/gnu/packages/multiprecision.scm
+++ b/gnu/packages/multiprecision.scm
@@ -10,6 +10,7 @@
 ;;; Copyright © 2021 Vinicius Monego <[email-masked]>
 ;;; Copyright © 2022 Maxim Cournoyer <[email-masked]>
 ;;; Copyright © 2023 Janneke Nieuwenhuizen <[email-masked]>
+;;; Copyright © 2023 Sharlatan Hellseher <[email-masked]>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -263,18 +264,18 @@ (define-public qd
     (native-inputs
      (list gfortran))
     (arguments
-     `(#:configure-flags `("--disable-enable_fma" ;weird :/
-                           "--disable-static"
-                           "--enable-shared"
-                           ,,@(if (string-prefix? "aarch64"
-                                                  (or (%current-target-system)
-                                                      (%current-system)))
-                                  ;; XXX: The qd_test test fails numerical
-                                  ;; accuracy checks for 'dd_real::exp()' on
-                                  ;; aarch64 with GCC 5.4 at -O2.  Disabling
-                                  ;; expensive optimizations lets it pass.
-                                  '("CXXFLAGS=-O3 -fno-expensive-optimizations")
-                                  '("CXXFLAGS=-O3")))))
+     (list
+      #:configure-flags
+      #~(list "--disable-enable_fma" ;weird :/
+              "--disable-static"
+              "--enable-shared"
+              #$@(if (target-aarch64?)
+                     ;; XXX: The qd_test test fails numerical
+                     ;; accuracy checks for 'dd_real::exp()' on
+                     ;; aarch64 with GCC 5.4 at -O2.  Disabling
+                     ;; expensive optimizations lets it pass.
+                     '("CXXFLAGS=-O3 -fno-expensive-optimizations")
+                     '("CXXFLAGS=-O3")))))
     (home-page "https://www.davidhbailey.com/dhbsoftware/")
     (synopsis "Double-double and quad-double library")
     (description "This package supports both a double-double

base-commit: 0647f308b46b7ba7aa136068712f8d82d69d1a35
-- 
2.41.0